diff --git a/xhprof_html/callgraph.php b/xhprof_html/callgraph.php
index 46fc6a52..22d1c2f2 100644
--- a/xhprof_html/callgraph.php
+++ b/xhprof_html/callgraph.php
@@ -47,8 +47,8 @@
// parents/children functions of it will be shown.
'func' => array(XHPROF_STRING_PARAM, ''),
- // image type, can be 'jpg', 'gif', 'ps', 'png'
- 'type' => array(XHPROF_STRING_PARAM, 'png'),
+ // image type, can be 'jpg', 'gif', 'ps', 'png', 'svg'
+ 'type' => array(XHPROF_STRING_PARAM, 'svg'),
// only functions whose exclusive time over the total time
// is larger than this threshold will be shown.